@@ -1,21 +1,23 @@
-__version__ = '0.6.2'
+__version__ = '0.7.1'
 
 from .api_types import (BaseTelegram, CallbackQuery, Chat, ChosenInlineResult,
                         Contact, File, InlineKeyboardButton,
                         InlineKeyboardMarkup, InlineQuery, KeyboardButton,
                         LocalFile, Message, PreCheckoutQuery,
                         ReplyKeyboardMarkup, ReplyKeyboardRemove,
-                        ShippingQuery, User)
-from .bot import Bot, FilterProtocol, StreamFile
+                        ShippingQuery, StreamFile, User)
+from .bot import Bot, FilterProtocol, PollBot
 from .bot_update import BotUpdate
 from .constants import (ChatAction, ChatType, ContentType, ParseMode, PollType,
                         UpdateType)
 from .exceptions import (BadGateway, BotBlocked, BotKicked, MigrateToChat,
                          RestartingTelegram, RetryAfter, TelegramError)
-from .filters import (CallbackQueryDataFilter, CommandsFilter,
+from .filters import (ANDFilter, CallbackQueryDataFilter, CommandsFilter,
                       ContentTypeFilter, GroupChatFilter, MessageTextFilter,
-                      PrivateChatFilter, StateFilter, UpdateTypeFilter)
+                      ORFilter, PrivateChatFilter, StateFilter,
+                      UpdateTypeFilter)
 from .handler_table import HandlerTable
+from .runner import ContextFunction, Runner
 from .storage import StorageProtocol
 
 __all__ = (
@@ -39,6 +41,7 @@ __all__ = (
 
     'FilterProtocol',
     'Bot',
+    'PollBot',
     'LocalFile',
     'StreamFile',
 
@@ -67,8 +70,13 @@ __all__ = (
     'CallbackQueryDataFilter',
     'StateFilter',
     'UpdateTypeFilter',
+    'ORFilter',
+    'ANDFilter',
 
     'HandlerTable',
 
-    'StorageProtocol'
+    'StorageProtocol',
+
+    'ContextFunction',
+    'Runner'
 )
