@@ -18,10 +18,12 @@ from .constants import (ChatAction, DiceEmoji, ParseMode, PollType,
                         RequestMethod, UpdateType)
 from .helpers import json_dumps
 
+__all__ = ('ParamType', 'ApiMethods')
+
 api_logger: Final[logging.Logger] = logging.getLogger('aiotgbot.api')
 
 
-def _to_json(
+def _json_dumps(
     value: Union[BaseTelegram, Iterable[BaseTelegram], None]
 ) -> Optional[str]:
     if value is None:
@@ -48,7 +50,6 @@ ParamType = Union[int, float, str, InputFile, None]
 
 
 class ApiMethods(ABC):
-    __slots__ = ()
 
     @abstractmethod
     async def _request(self, http_method: RequestMethod, api_method: str,
@@ -89,16 +90,17 @@ class ApiMethods(ABC):
             ip_address=ip_address, max_connections=max_connections,
             allowed_updates=_strs_to_json(allowed_updates),
             drop_pending_updates=drop_pending_updates)
-
+        assert isinstance(response.result, bool)
         return response.result
 
     async def delete_webhook(
-        self, drop_pending_updates: Optional[bool]
+        self, drop_pending_updates: Optional[bool] = None
     ) -> bool:
         api_logger.debug('Delete webhook')
         response = await self._request(
             RequestMethod.POST, 'deleteWebhook',
             drop_pending_updates=drop_pending_updates)
+        assert isinstance(response.result, bool)
         return response.result
 
     async def get_webhook_info(self) -> WebhookInfo:
@@ -115,11 +117,13 @@ class ApiMethods(ABC):
     async def log_out(self) -> bool:
         api_logger.debug('Log out')
         response = await self._request(RequestMethod.POST, 'logOut')
+        assert isinstance(response.result, bool)
         return response.result
 
     async def close(self) -> bool:
         api_logger.debug('Close')
         response = await self._request(RequestMethod.POST, 'close')
+        assert isinstance(response.result, bool)
         return response.result
 
     async def send_message(
@@ -132,16 +136,16 @@ class ApiMethods(ABC):
         allow_sending_without_reply: Optional[bool] = None,
         reply_markup: Optional[ReplyMarkup] = None
     ) -> Message:
-        api_logger.debug('Send message "%s" to chat "%s"', text, chat_id)
+        api_logger.debug('Send message %r to chat "%s"', text, chat_id)
         response = await self._safe_request(
             RequestMethod.POST, 'sendMessage', chat_id, text=text,
             parse_mode=_parse_mode_to_str(parse_mode),
-            entities=_to_json(entities),
+            entities=_json_dumps(entities),
             disable_web_page_preview=disable_web_page_preview,
             disable_notification=disable_notification,
             reply_to_message_id=reply_to_message_id,
             allow_sending_without_reply=allow_sending_without_reply,
-            reply_markup=_to_json(reply_markup))
+            reply_markup=_json_dumps(reply_markup))
 
         return Message.from_dict(response.result)
 
@@ -173,11 +177,12 @@ class ApiMethods(ABC):
         response = await self._safe_request(
             RequestMethod.POST, 'copyMessage', chat_id,
             from_chat_id=from_chat_id, message_id=message_id,
-            parse_mode=parse_mode, caption_entities=_to_json(caption_entities),
+            parse_mode=parse_mode,
+            caption_entities=_json_dumps(caption_entities),
             caption=caption, disable_notification=disable_notification,
             reply_to_message_id=reply_to_message_id,
             allow_sending_without_reply=allow_sending_without_reply,
-            reply_markup=_to_json(reply_markup))
+            reply_markup=_json_dumps(reply_markup))
 
         return MessageId.from_dict(response.result)
 
@@ -196,11 +201,11 @@ class ApiMethods(ABC):
         response = await self._safe_request(
             RequestMethod.POST, 'sendPhoto', chat_id, photo=photo,
             caption=caption, parse_mode=_parse_mode_to_str(parse_mode),
-            caption_entities=_to_json(caption_entities),
+            caption_entities=_json_dumps(caption_entities),
             disable_notification=disable_notification,
             reply_to_message_id=reply_to_message_id,
             allow_sending_without_reply=allow_sending_without_reply,
-            reply_markup=_to_json(reply_markup))
+            reply_markup=_json_dumps(reply_markup))
 
         return Message.from_dict(response.result)
 
@@ -223,13 +228,13 @@ class ApiMethods(ABC):
         response = await self._safe_request(
             RequestMethod.POST, 'sendAudio', chat_id, audio=audio,
             caption=caption, parse_mode=_parse_mode_to_str(parse_mode),
-            caption_entities=_to_json(caption_entities),
+            caption_entities=_json_dumps(caption_entities),
             disable_notification=disable_notification,
             duration=duration, performer=performer,
             title=title, thumb=thumb,
             reply_to_message_id=reply_to_message_id,
             allow_sending_without_reply=allow_sending_without_reply,
-            reply_markup=_to_json(reply_markup))
+            reply_markup=_json_dumps(reply_markup))
 
         return Message.from_dict(response.result)
 
@@ -254,13 +259,13 @@ class ApiMethods(ABC):
             RequestMethod.POST, 'sendDocument', chat_id,
             document=document, thumb=thumb, caption=caption,
             parse_mode=_parse_mode_to_str(parse_mode),
-            caption_entities=_to_json(caption_entities),
+            caption_entities=_json_dumps(caption_entities),
             disable_content_type_detection=disable_content_type_detection,
             disable_notification=disable_notification,
             duration=duration, performer=performer, title=title,
             reply_to_message_id=reply_to_message_id,
             allow_sending_without_reply=allow_sending_without_reply,
-            reply_markup=_to_json(reply_markup))
+            reply_markup=_json_dumps(reply_markup))
 
         return Message.from_dict(response.result)
 
@@ -286,12 +291,12 @@ class ApiMethods(ABC):
             video=video, duration=duration, width=width,
             height=height, thumb=thumb, caption=caption,
             parse_mode=_parse_mode_to_str(parse_mode),
-            caption_entities=_to_json(caption_entities),
+            caption_entities=_json_dumps(caption_entities),
             supports_streaming=supports_streaming,
             disable_notification=disable_notification,
             reply_to_message_id=reply_to_message_id,
             allow_sending_without_reply=allow_sending_without_reply,
-            reply_markup=_to_json(reply_markup))
+            reply_markup=_json_dumps(reply_markup))
 
         return Message.from_dict(response.result)
 
@@ -316,11 +321,11 @@ class ApiMethods(ABC):
             animation=animation, duration=duration, width=width,
             height=height, thumb=thumb, caption=caption,
             parse_mode=_parse_mode_to_str(parse_mode),
-            caption_entities=_to_json(caption_entities),
+            caption_entities=_json_dumps(caption_entities),
             disable_notification=disable_notification,
             reply_to_message_id=reply_to_message_id,
             allow_sending_without_reply=allow_sending_without_reply,
-            reply_markup=_to_json(reply_markup))
+            reply_markup=_json_dumps(reply_markup))
 
         return Message.from_dict(response.result)
 
@@ -341,12 +346,12 @@ class ApiMethods(ABC):
             RequestMethod.POST, 'sendVoice', chat_id,
             voice=voice, caption=caption,
             parse_mode=_parse_mode_to_str(parse_mode),
-            caption_entities=_to_json(caption_entities),
+            caption_entities=_json_dumps(caption_entities),
             duration=duration,
             disable_notification=disable_notification,
             reply_to_message_id=reply_to_message_id,
             allow_sending_without_reply=allow_sending_without_reply,
-            reply_markup=_to_json(reply_markup))
+            reply_markup=_json_dumps(reply_markup))
 
         return Message.from_dict(response.result)
 
@@ -369,7 +374,7 @@ class ApiMethods(ABC):
             disable_notification=disable_notification,
             reply_to_message_id=reply_to_message_id,
             allow_sending_without_reply=allow_sending_without_reply,
-            reply_markup=_to_json(reply_markup))
+            reply_markup=_json_dumps(reply_markup))
 
         return Message.from_dict(response.result)
 
@@ -428,7 +433,7 @@ class ApiMethods(ABC):
             disable_notification=disable_notification,
             reply_to_message_id=reply_to_message_id,
             allow_sending_without_reply=allow_sending_without_reply,
-            reply_markup=_to_json(reply_markup))
+            reply_markup=_json_dumps(reply_markup))
 
         return Message.from_dict(response.result)
 
@@ -452,7 +457,7 @@ class ApiMethods(ABC):
             latitude=latitude, longitude=longitude,
             horizontal_accuracy=horizontal_accuracy, heading=heading,
             proximity_alert_radius=proximity_alert_radius,
-            reply_markup=_to_json(reply_markup))
+            reply_markup=_json_dumps(reply_markup))
 
         if isinstance(response.result, bool):
             return response.result
@@ -470,7 +475,7 @@ class ApiMethods(ABC):
             RequestMethod.POST, 'stopMessageLiveLocation',
             chat_id=chat_id, message_id=message_id,
             inline_message_id=inline_message_id,
-            reply_markup=_to_json(reply_markup))
+            reply_markup=_json_dumps(reply_markup))
 
         if isinstance(response.result, bool):
             return response.result
@@ -499,7 +504,7 @@ class ApiMethods(ABC):
             disable_notification=disable_notification,
             reply_to_message_id=reply_to_message_id,
             allow_sending_without_reply=allow_sending_without_reply,
-            reply_markup=_to_json(reply_markup))
+            reply_markup=_json_dumps(reply_markup))
 
         return Message.from_dict(response.result)
 
@@ -522,7 +527,7 @@ class ApiMethods(ABC):
             disable_notification=disable_notification,
             reply_to_message_id=reply_to_message_id,
             allow_sending_without_reply=allow_sending_without_reply,
-            reply_markup=_to_json(reply_markup))
+            reply_markup=_json_dumps(reply_markup))
 
         return Message.from_dict(response.result)
 
@@ -552,14 +557,14 @@ class ApiMethods(ABC):
             correct_option_id=correct_option_id,
             is_closed=is_closed, explanation=explanation,
             explanation_parse_mode=explanation_parse_mode,
-            explanation_entities=_to_json(explanation_entities),
+            explanation_entities=_json_dumps(explanation_entities),
             open_period=open_period, close_date=close_date,
             disable_notification=disable_notification,
             reply_to_message_id=reply_to_message_id,
             allow_sending_without_reply=allow_sending_without_reply,
-            reply_markup=_to_json(reply_markup))
+            reply_markup=_json_dumps(reply_markup))
 
-        return response.result
+        return Message.from_dict(response.result)
 
     async def send_dice(self, chat_id: Union[int, str],
                         emoji: Optional[DiceEmoji] = None,
@@ -574,16 +579,16 @@ class ApiMethods(ABC):
             disable_notification=disable_notification,
             reply_to_message_id=reply_to_message_id,
             allow_sending_without_reply=allow_sending_without_reply,
-            reply_markup=_to_json(reply_markup))
+            reply_markup=_json_dumps(reply_markup))
 
-        return response.result
+        return Message.from_dict(response.result)
 
     async def send_chat_action(self, chat_id: Union[int, str],
                                action: ChatAction) -> bool:
         api_logger.debug('Send action "%s" to chat "%s"', action, chat_id)
         response = await self._safe_request(
             RequestMethod.POST, 'sendChatAction', chat_id, action=action.value)
-
+        assert isinstance(response.result, bool)
         return response.result
 
     async def get_user_profile_photos(
@@ -610,7 +615,7 @@ class ApiMethods(ABC):
         response = await self._request(
             RequestMethod.POST, 'kickChatMember',
             chat_id=chat_id, user_id=user_id, until_date=until_date)
-
+        assert isinstance(response.result, bool)
         return response.result
 
     async def unban_chat_member(self, chat_id: Union[int, str], user_id: int,
@@ -619,7 +624,7 @@ class ApiMethods(ABC):
         response = await self._request(RequestMethod.POST, 'unbanChatMember',
                                        chat_id=chat_id, user_id=user_id,
                                        only_if_banned=only_if_banned)
-
+        assert isinstance(response.result, bool)
         return response.result
 
     async def restrict_chat_member(
@@ -633,7 +638,7 @@ class ApiMethods(ABC):
             RequestMethod.POST, 'restrictChatMember', chat_id=chat_id,
             user_id=user_id, permissions=json_dumps(permissions.to_dict()),
             until_date=until_date)
-
+        assert isinstance(response.result, bool)
         return response.result
 
     async def promote_chat_member(
@@ -661,7 +666,7 @@ class ApiMethods(ABC):
             can_restrict_members=can_restrict_members,
             can_pin_messages=can_pin_messages,
             can_promote_members=can_promote_members)
-
+        assert isinstance(response.result, bool)
         return response.result
 
     async def set_chat_administrator_custom_title(
@@ -674,14 +679,14 @@ class ApiMethods(ABC):
         response = await self._request(
             RequestMethod.POST, 'setChatAdministratorCustomTitle',
             chat_id=chat_id, user_id=user_id, custom_title=custom_title)
-
+        assert isinstance(response.result, bool)
         return response.result
 
     async def export_chat_invite_link(self, chat_id: Union[int, str]) -> str:
         api_logger.debug('Export chat "%s" invite link', chat_id)
         response = await self._request(
             RequestMethod.POST, 'exportChatInviteLink', chat_id=chat_id)
-
+        assert isinstance(response.result, str)
         return response.result
 
     async def set_chat_permissions(
@@ -692,7 +697,7 @@ class ApiMethods(ABC):
         response = await self._safe_request(
             RequestMethod.POST, 'setChatPermissions', chat_id,
             permissions=json_dumps(permissions.to_dict()))
-
+        assert isinstance(response.result, bool)
         return response.result
 
     async def set_chat_photo(
@@ -702,14 +707,14 @@ class ApiMethods(ABC):
         api_logger.debug('Set chat "%s" photo', chat_id)
         response = await self._safe_request(RequestMethod.POST, 'setChatPhoto',
                                             chat_id, photo=photo)
-
+        assert isinstance(response.result, bool)
         return response.result
 
     async def delete_chat_photo(self, chat_id: Union[int, str]) -> bool:
         api_logger.debug('Delete chat "%s" photo', chat_id)
         response = await self._request(RequestMethod.POST, 'deleteChatPhoto',
                                        chat_id=chat_id)
-
+        assert isinstance(response.result, bool)
         return response.result
 
     async def set_chat_title(self, chat_id: Union[int, str],
@@ -717,7 +722,7 @@ class ApiMethods(ABC):
         api_logger.debug('Set title "%s" for chat "%s"', title, chat_id)
         response = await self._request(RequestMethod.POST, 'setChatTitle',
                                        chat_id=chat_id, title=title)
-
+        assert isinstance(response.result, bool)
         return response.result
 
     async def set_chat_description(self, chat_id: Union[int, str],
@@ -726,7 +731,7 @@ class ApiMethods(ABC):
         response = await self._request(
             RequestMethod.POST, 'setChatDescription', chat_id=chat_id,
             description=description)
-
+        assert isinstance(response.result, bool)
         return response.result
 
     async def pin_chat_message(
@@ -738,7 +743,7 @@ class ApiMethods(ABC):
             RequestMethod.POST, 'pinChatMessage',
             chat_id=chat_id, message_id=message_id,
             disable_notification=disable_notification)
-
+        assert isinstance(response.result, bool)
         return response.result
 
     async def unpin_chat_message(self, chat_id: Union[int, str],
@@ -747,21 +752,21 @@ class ApiMethods(ABC):
                          message_id, chat_id)
         response = await self._request(RequestMethod.POST, 'unpinChatMessage',
                                        chat_id=chat_id, message_id=message_id)
-
+        assert isinstance(response.result, bool)
         return response.result
 
     async def unpin_all_chat_messages(self, chat_id: Union[int, str]) -> bool:
         api_logger.debug('Unpin all messages in chat "%s"', chat_id)
         response = await self._request(RequestMethod.POST,
                                        'unpinAllChatMessages', chat_id=chat_id)
-
+        assert isinstance(response.result, bool)
         return response.result
 
     async def leave_chat(self, chat_id: Union[int, str]) -> bool:
         api_logger.debug('Leave chat "%s"', chat_id)
         response = await self._request(RequestMethod.POST, 'leaveChat',
                                        chat_id=chat_id)
-
+        assert isinstance(response.result, bool)
         return response.result
 
     async def get_chat(self, chat_id: Union[int, str]) -> Chat:
@@ -783,7 +788,7 @@ class ApiMethods(ABC):
         api_logger.debug('Get chat members count "%s"', chat_id)
         response = await self._request(
             RequestMethod.GET, 'getChatMembersCount', chat_id=chat_id)
-
+        assert isinstance(response.result, int)
         return response.result
 
     async def get_chat_member(self, chat_id: Union[int, str],
@@ -801,14 +806,14 @@ class ApiMethods(ABC):
         response = await self._request(
             RequestMethod.POST, 'setChatStickerSet', chat_id=chat_id,
             sticker_set_name=sticker_set_name)
-
+        assert isinstance(response.result, bool)
         return response.result
 
     async def delete_chat_sticker_set(self, chat_id: Union[int, str]) -> bool:
         api_logger.debug('Delete chat "%s" sticker set', chat_id)
         response = await self._request(RequestMethod.POST,
                                        'deleteChatStickerSet', chat_id=chat_id)
-
+        assert isinstance(response.result, bool)
         return response.result
 
     async def answer_callback_query(self, callback_query_id: str,
@@ -821,7 +826,7 @@ class ApiMethods(ABC):
             RequestMethod.POST, 'answerCallbackQuery',
             callback_query_id=callback_query_id, text=text,
             show_alert=show_alert, url=url, cache_time=cache_time)
-
+        assert isinstance(response.result, bool)
         return response.result
 
     async def set_my_commands(self, commands: Iterable[BotCommand]) -> bool:
@@ -830,7 +835,7 @@ class ApiMethods(ABC):
             RequestMethod.POST, 'setMyCommands',
             commands=json_dumps(tuple(command.to_dict()
                                       for command in commands)))
-
+        assert isinstance(response.result, bool)
         return response.result
 
     async def get_my_commands(self) -> Tuple[BotCommand, ...]:
@@ -850,6 +855,12 @@ class ApiMethods(ABC):
         disable_web_page_preview: Optional[bool] = None,
         reply_markup: Optional[InlineKeyboardMarkup] = None
     ) -> Union[Message, bool]:
+        if (
+            (chat_id is None or message_id is None) and
+            inline_message_id is None
+        ):
+            raise RuntimeError('chat_id or message_id and '
+                               'inline_message_id is None')
         if inline_message_id is None:
             api_logger.debug('Edit message %s in "%s" text',
                              message_id, chat_id)
@@ -861,9 +872,9 @@ class ApiMethods(ABC):
             chat_id=chat_id, message_id=message_id,
             inline_message_id=inline_message_id, text=text,
             parse_mode=_parse_mode_to_str(parse_mode),
-            entities=_to_json(entities),
+            entities=_json_dumps(entities),
             disable_web_page_preview=disable_web_page_preview,
-            reply_markup=_to_json(reply_markup))
+            reply_markup=_json_dumps(reply_markup))
 
         if isinstance(response.result, bool):
             return response.result
@@ -871,7 +882,8 @@ class ApiMethods(ABC):
             return Message.from_dict(response.result)
 
     async def edit_message_caption(
-        self, chat_id: Optional[Union[int, str]] = None,
+        self,
+        chat_id: Optional[Union[int, str]] = None,
         message_id: Optional[int] = None,
         inline_message_id: Optional[str] = None,
         caption: Optional[str] = None,
@@ -879,6 +891,12 @@ class ApiMethods(ABC):
         caption_entities: Optional[Iterable[MessageEntity]] = None,
         reply_markup: Optional[InlineKeyboardMarkup] = None
     ) -> Union[Message, bool]:
+        if (
+            (chat_id is None or message_id is None) and
+            inline_message_id is None
+        ):
+            raise RuntimeError('chat_id or message_id and '
+                               'inline_message_id is None')
         if inline_message_id is None:
             api_logger.debug('Edit message %s in "%s" caption',
                              message_id, chat_id)
@@ -890,8 +908,8 @@ class ApiMethods(ABC):
             chat_id=chat_id, message_id=message_id,
             inline_message_id=inline_message_id,
             caption=caption, parse_mode=_parse_mode_to_str(parse_mode),
-            caption_entities=_to_json(caption_entities),
-            reply_markup=_to_json(reply_markup))
+            caption_entities=_json_dumps(caption_entities),
+            reply_markup=_json_dumps(reply_markup))
 
         if isinstance(response.result, bool):
             return response.result
@@ -899,12 +917,18 @@ class ApiMethods(ABC):
             return Message.from_dict(response.result)
 
     async def edit_message_media(
-        self, chat_id: Optional[Union[int, str]] = None,
+        self, media: InputMedia,
+        chat_id: Optional[Union[int, str]] = None,
         message_id: Optional[int] = None,
         inline_message_id: Optional[str] = None,
-        media: InputMedia = None,
         reply_markup: Optional[InlineKeyboardMarkup] = None
     ) -> Union[Message, bool]:
+        if (
+            (chat_id is None or message_id is None) and
+            inline_message_id is None
+        ):
+            raise RuntimeError('chat_id or message_id and '
+                               'inline_message_id is None')
         if inline_message_id is None:
             api_logger.debug('Edit message %s in "%s" media',
                              message_id, chat_id)
@@ -912,14 +936,14 @@ class ApiMethods(ABC):
             api_logger.debug('Edit inline message "%s" media',
                              inline_message_id)
         attachments = {}
-        if media is not None and not isinstance(media.media, str):
+        if not isinstance(media.media, str):
             attachment_name = 'attachment0'
             attachments[attachment_name] = media.media
             media = attr.evolve(media, media=f'attach://{attachment_name}')
         response = await self._request(
             RequestMethod.POST, 'editMessageMedia', chat_id=chat_id,
             message_id=message_id, inline_message_id=inline_message_id,
-            media=_to_json(media), reply_markup=_to_json(reply_markup),
+            media=_json_dumps(media), reply_markup=_json_dumps(reply_markup),
             **attachments)
         if isinstance(response.result, bool):
             return response.result
@@ -932,6 +956,12 @@ class ApiMethods(ABC):
         inline_message_id: Optional[str] = None,
         reply_markup: Optional[InlineKeyboardMarkup] = None
     ) -> Union[Message, bool]:
+        if (
+            (chat_id is None or message_id is None) and
+            inline_message_id is None
+        ):
+            raise RuntimeError('chat_id or message_id and '
+                               'inline_message_id is None')
         if inline_message_id is None:
             api_logger.debug('Edit message %s in "%s" reply markup',
                              message_id, chat_id)
@@ -942,7 +972,7 @@ class ApiMethods(ABC):
             RequestMethod.POST, 'editMessageReplyMarkup',
             chat_id=chat_id, message_id=message_id,
             inline_message_id=inline_message_id,
-            reply_markup=_to_json(reply_markup))
+            reply_markup=_json_dumps(reply_markup))
 
         if isinstance(response.result, bool):
             return response.result
@@ -950,24 +980,23 @@ class ApiMethods(ABC):
             return Message.from_dict(response.result)
 
     async def stop_poll(
-        self, chat_id: Union[int, str],
-        message_id: int = None,
+        self, chat_id: Union[int, str], message_id: int,
         reply_markup: Optional[InlineKeyboardMarkup] = None
     ) -> Poll:
         api_logger.debug('Stop poll %s in "%s"', message_id, chat_id)
         response = await self._request(
             RequestMethod.POST, 'stopPoll',
             chat_id=chat_id, message_id=message_id,
-            reply_markup=_to_json(reply_markup))
+            reply_markup=_json_dumps(reply_markup))
 
-        return response.result
+        return Poll.from_dict(response.result)
 
     async def delete_message(self, chat_id: Optional[Union[int, str]] = None,
                              message_id: Optional[int] = None) -> bool:
         api_logger.debug('Delete message %s in "%s"', message_id, chat_id)
         response = await self._request(RequestMethod.POST, 'deleteMessage',
                                        chat_id=chat_id, message_id=message_id)
-
+        assert isinstance(response.result, bool)
         return response.result
 
     async def send_sticker(
@@ -985,7 +1014,7 @@ class ApiMethods(ABC):
             disable_notification=disable_notification,
             reply_to_message_id=reply_to_message_id,
             allow_sending_without_reply=allow_sending_without_reply,
-            reply_markup=_to_json(reply_markup))
+            reply_markup=_json_dumps(reply_markup))
 
         return Message.from_dict(response.result)
 
@@ -1018,8 +1047,8 @@ class ApiMethods(ABC):
             user_id=user_id, name=name, title=title, emojis=emojis,
             png_sticker=png_sticker, tgs_sticker=tgs_sticker,
             contains_masks=contains_masks,
-            mask_position=_to_json(mask_position))
-
+            mask_position=_json_dumps(mask_position))
+        assert isinstance(response.result, bool)
         return response.result
 
     async def add_sticker_to_set(
@@ -1031,7 +1060,7 @@ class ApiMethods(ABC):
         response = await self._request(
             RequestMethod.POST, 'addStickerToSet',
             user_id=user_id, name=name, title=title, png_sticker=png_sticker,
-            emojis=emojis, mask_position=_to_json(mask_position))
+            emojis=emojis, mask_position=_json_dumps(mask_position))
 
         return File.from_dict(response.result)
 
@@ -1041,14 +1070,14 @@ class ApiMethods(ABC):
         response = await self._request(
             RequestMethod.POST, 'setStickerPositionInSet',
             sticker=sticker, position=position)
-
+        assert isinstance(response.result, bool)
         return response.result
 
     async def delete_sticker_from_set(self, sticker: str) -> bool:
         api_logger.debug('Delete sticker "%s" from set', sticker)
         response = await self._request(
             RequestMethod.POST, 'deleteStickerFromSet', sticker=sticker)
-
+        assert isinstance(response.result, bool)
         return response.result
 
     async def set_sticker_set_thumb(
@@ -1060,7 +1089,7 @@ class ApiMethods(ABC):
         response = await self._request(
             RequestMethod.POST, 'setStickerSetThumb',
             name=name, user_id=user_id, thumb=thumb)
-
+        assert isinstance(response.result, bool)
         return response.result
 
     async def answer_inline_query(
@@ -1078,7 +1107,7 @@ class ApiMethods(ABC):
             cache_time=cache_time, is_personal=is_personal,
             next_offset=next_offset, switch_pm_text=switch_pm_text,
             switch_pm_parameter=switch_pm_parameter)
-
+        assert isinstance(response.result, bool)
         return response.result
 
     async def send_invoice(
@@ -1117,7 +1146,7 @@ class ApiMethods(ABC):
             disable_notification=disable_notification,
             reply_to_message_id=reply_to_message_id,
             allow_sending_without_reply=allow_sending_without_reply,
-            reply_markup=_to_json(reply_markup))
+            reply_markup=_json_dumps(reply_markup))
 
         return Message.from_dict(response.result)
 
@@ -1137,7 +1166,7 @@ class ApiMethods(ABC):
             inline_query_id=inline_query_id, ok=ok,
             shipping_options=shipping_options_json,
             error_message=error_message)
-
+        assert isinstance(response.result, bool)
         return response.result
 
     async def answer_pre_checkout_query(
@@ -1150,7 +1179,7 @@ class ApiMethods(ABC):
             RequestMethod.POST, 'answerPreCheckoutQuery',
             pre_checkout_query_id=pre_checkout_query_id, ok=ok,
             error_message=error_message)
-
+        assert isinstance(response.result, bool)
         return response.result
 
     async def set_passport_data_errors(
@@ -1162,7 +1191,7 @@ class ApiMethods(ABC):
             RequestMethod.POST, 'setPassportDataErrors',
             user_id=user_id,
             errors=json_dumps(tuple(error.to_dict() for error in errors)))
-
+        assert isinstance(response.result, bool)
         return response.result
 
     async def send_game(
@@ -1179,7 +1208,7 @@ class ApiMethods(ABC):
             disable_notification=disable_notification,
             reply_to_message_id=reply_to_message_id,
             allow_sending_without_reply=allow_sending_without_reply,
-            reply_markup=_to_json(reply_markup))
+            reply_markup=_json_dumps(reply_markup))
 
         return Message.from_dict(response.result)
 
