@@ -1,17 +1,19 @@
 import asyncio
+import json
 import logging
 from abc import abstractmethod
 from functools import partial
 from http import HTTPStatus
-from signal import SIGINT, SIGTERM
 from typing import (Any, Awaitable, Callable, Dict, Final, Iterator,
                     MutableMapping, Optional, Protocol, Tuple, Union,
                     runtime_checkable)
 
-import aiohttp
 import aiojobs
 import attr
 import backoff
+from aiofreqlimit import FreqLimit
+from aiohttp import (BaseConnector, ClientError, ClientSession, FormData,
+                     TCPConnector)
 from aiojobs_protocols import SchedulerProtocol
 
 from .api_methods import ApiMethods, ParamType
@@ -20,9 +22,12 @@ from .bot_update import BotUpdate, Context
 from .constants import ChatType, RequestMethod
 from .exceptions import (BadGateway, BotBlocked, BotKicked, MigrateToChat,
                          RestartingTelegram, RetryAfter, TelegramError)
-from .helpers import FreqLimit, KeyLock, get_software, json_dumps
+from .helpers import KeyLock, get_software, json_dumps
 from .storage import StorageProtocol
 
+__all__ = ('Bot', 'PollBot', 'HandlerCallable', 'Handler',
+           'HandlerTableProtocol', 'FilterProtocol')
+
 SOFTWARE: Final[str] = get_software()
 TG_API_URL: Final[str] = 'https://api.telegram.org/bot{token}/{method}'
 TG_FILE_URL: Final[str] = 'https://api.telegram.org/file/bot{token}/{path}'
@@ -40,31 +45,44 @@ EventHandler = Callable[['Bot'], Awaitable[None]]
 
 
 class Bot(MutableMapping[str, Any], ApiMethods):
-    __slots__ = ('_token', '_handler_table', '_storage', '_client',
-                 '_context_lock', '_message_limit', '_chat_limit',
-                 '_group_limit', '_scheduler', '_updates_offset', '_me',
-                 '_on_shutdown', '_poll_task', '_polling_started', '_data')
 
-    def __init__(self, token: str, handler_table: 'HandlerTableProtocol',
-                 storage: StorageProtocol) -> None:
+    def __init__(
+        self,
+        token: str,
+        handler_table: 'HandlerTableProtocol',
+        storage: StorageProtocol,
+        connector: Optional[BaseConnector] = None
+    ) -> None:
+        if not handler_table.frozen:
+            raise RuntimeError('Can\'t use unfrozen handler table')
+        if not isinstance(handler_table, HandlerTableProtocol):
+            raise RuntimeError('Handler table is not HandlerTableProtocol '
+                               'instance')
+        if not isinstance(storage, StorageProtocol):
+            raise RuntimeError('Storage parameter is not StorageProtocol '
+                               'instance')
         self._token: Final[str] = token
         self._handler_table: Final['HandlerTableProtocol'] = handler_table
         self._storage: Final[StorageProtocol] = storage
-        self._client: Optional[aiohttp.ClientSession] = None
-        self._context_lock: Optional[KeyLock] = None
-        self._message_limit: Optional[FreqLimit] = None
-        self._chat_limit: Optional[FreqLimit] = None
-        self._group_limit: Optional[FreqLimit] = None
+        if connector is not None:
+            _connector: BaseConnector = connector
+        else:
+            _connector = TCPConnector(keepalive_timeout=60)
+        self._client: Final[ClientSession] = ClientSession(
+            connector=_connector,
+            json_serialize=json_dumps,
+            headers={'User-Agent': SOFTWARE}
+        )
+        self._context_lock: Final[KeyLock] = KeyLock()
+        self._message_limit: Final[FreqLimit] = FreqLimit(MESSAGE_INTERVAL)
+        self._chat_limit: Final[FreqLimit] = FreqLimit(CHAT_INTERVAL)
+        self._group_limit: Final[FreqLimit] = FreqLimit(GROUP_INTERVAL)
         self._scheduler: Optional[SchedulerProtocol] = None
+        self._started: bool = False
+        self._stopped: bool = False
         self._updates_offset: int = 0
         self._me: Optional[User] = None
-        self._on_shutdown: Optional[EventHandler] = None
-        self._poll_task: Optional[asyncio.Task] = None
-        self._polling_started: bool = False
-        self._data: Dict[str, Any] = {}
-
-        if not self._handler_table.frozen:
-            self._handler_table.freeze()
+        self._data: Final[Dict[str, Any]] = {}
 
     def __getitem__(self, key: str) -> Any:
         return self._data[key]
@@ -86,97 +104,27 @@ class Bot(MutableMapping[str, Any], ApiMethods):
         return self._storage
 
     @property
-    def client(self) -> aiohttp.ClientSession:
+    def client(self) -> ClientSession:
         if self._client is None:
             raise RuntimeError('Access to client during bot is not running.')
         else:
             return self._client
 
-    async def poll(self, on_startup: Optional[EventHandler] = None,
-                   on_shutdown: Optional[EventHandler] = None):
-        loop = asyncio.get_running_loop()
-
-        connector = aiohttp.TCPConnector(keepalive_timeout=60)
-        self._client = aiohttp.ClientSession(
-            connector=connector,
-            json_serialize=json_dumps,
-            headers={'User-Agent': SOFTWARE}
-        )
-
-        self._context_lock = KeyLock()
-        self._message_limit = FreqLimit(MESSAGE_INTERVAL)
-        self._chat_limit = FreqLimit(CHAT_INTERVAL)
-        self._group_limit = FreqLimit(GROUP_INTERVAL)
-
-        if on_startup is not None:
-            await on_startup(self)
-        self._on_shutdown = on_shutdown
-
-        try:
-            self._me = await self.get_me()
-        except TelegramError as exception:
-            bot_logger.error('Got Telegram error "%s" for first API request. '
-                             'Seems like token is invalid.', exception)
-            await self._finish_polling()
-            return
-
-        loop.add_signal_handler(SIGINT, self.stop_polling)
-        loop.add_signal_handler(SIGTERM, self.stop_polling)
-
-        self._scheduler = await aiojobs.create_scheduler(
-            exception_handler=self._scheduler_exception_handler)
-
-        self._polling_started = True
-        self._poll_task = loop.create_task(self._poll())
-
-        bot_logger.info('Bot %s (%s) start polling', self._me.first_name,
-                        self._me.username)
-
-        try:
-            await self._poll_task
-        except asyncio.CancelledError:
-            pass
-        except Exception as exception:
-            bot_logger.exception('Error while polling updates',
-                                 exc_info=exception)
-
-        await self._scheduler.close()
-        await self._finish_polling()
-        bot_logger.info('Bot %s (%s) stop polling', self._me.first_name,
-                        self._me.username)
-
-    def stop_polling(self):
-        if not self._polling_started:
-            raise RuntimeError('Polling not started')
-        bot_logger.debug('Stop polling')
-        self._polling_started = False
-        if not self._poll_task.done():
-            self._poll_task.cancel()
-
-    async def _finish_polling(self):
-        if self._on_shutdown is not None:
-            await self._on_shutdown(self)
-
-        await self._client.close()
-        await self._storage.close()
-        await self._message_limit.clear()
-        await self._chat_limit.clear()
-        await self._group_limit.clear()
-
     def file_url(self, path: str) -> str:
         return TG_FILE_URL.format(token=self._token, path=path)
 
     @staticmethod
-    def _scheduler_exception_handler(_, context):
+    def _scheduler_exception_handler(_: SchedulerProtocol,
+                                     context: Dict[str, Any]) -> None:
         bot_logger.exception('Update handle error',
                              exc_info=context['exception'])
 
     @staticmethod
     def _telegram_exception(api_response: APIResponse) -> TelegramError:
+        assert api_response.error_code is not None
+        assert api_response.description is not None
         error_code = api_response.error_code
-        assert error_code is not None
         description = api_response.description
-        assert description is not None
         if (
             api_response.parameters is not None and
             api_response.parameters.retry_after is not None
@@ -200,7 +148,7 @@ class Bot(MutableMapping[str, Any], ApiMethods):
         else:
             return TelegramError(error_code, description)
 
-    @backoff.on_exception(backoff.expo, aiohttp.ClientError)
+    @backoff.on_exception(backoff.expo, ClientError)
     async def _request(
             self,
             http_method: RequestMethod,
@@ -211,7 +159,7 @@ class Bot(MutableMapping[str, Any], ApiMethods):
             name: str(value) if isinstance(value, (int,  float)) else value
             for name, value in params.items() if value is not None
         }
-        bot_logger.debug('Request %s %s %s', http_method, api_method, data)
+        bot_logger.debug('Request %s %s %r', http_method, api_method, data)
         if http_method == RequestMethod.GET:
             if len(data) > 0:
                 assert all(isinstance(value, str) for value in data.values())
@@ -219,7 +167,7 @@ class Bot(MutableMapping[str, Any], ApiMethods):
             else:
                 request = partial(self.client.get)
         else:
-            form_data = aiohttp.FormData()
+            form_data = FormData()
             for name, value in data.items():
                 if isinstance(value, (StreamFile, LocalFile)):
                     form_data.add_field(name, value.content,
@@ -231,7 +179,7 @@ class Bot(MutableMapping[str, Any], ApiMethods):
 
         url = TG_API_URL.format(token=self._token, method=api_method)
         async with request(url) as response:
-            response_dict = await response.json()
+            response_dict = json.loads(await response.read())
         response_logger.debug(response_dict)
         api_response = APIResponse.from_dict(response_dict)
 
@@ -252,13 +200,6 @@ class Bot(MutableMapping[str, Any], ApiMethods):
         request = partial(self._request, http_method, api_method,
                           chat_id=chat_id, **params)
 
-        assert self._message_limit is not None, 'Message limit not initialized'
-        assert self._group_limit is not None, 'Group limit not initialized'
-        assert self._chat_limit is not None, 'Chat limit not initialized'
-
-        if not self._polling_started:
-            raise RuntimeError('Polling not started')
-
         chat = await self.get_chat(chat_id)
         while True:
             try:
@@ -279,21 +220,6 @@ class Bot(MutableMapping[str, Any], ApiMethods):
                                      'retry not allowed')
                     raise
 
-    @backoff.on_exception(backoff.expo, TelegramError)
-    async def _poll(self) -> None:
-        assert self._scheduler is not None, 'Scheduler not initialized'
-
-        bot_logger.debug('Get updates from: %s', self._updates_offset)
-        while self._polling_started:
-            updates = await self.get_updates(offset=self._updates_offset,
-                                             timeout=TG_GET_UPDATES_TIMEOUT)
-
-            for update in updates:
-                await self._scheduler.spawn(self._handle_update(update))
-
-            if len(updates) > 0:
-                self._updates_offset = updates[-1].update_id + 1
-
     @staticmethod
     def _update_state(update: Update) -> str:
         user_id: Optional[int] = None
@@ -345,7 +271,7 @@ class Bot(MutableMapping[str, Any], ApiMethods):
             state = await self._storage.get(state_key)
             assert isinstance(state, str) or state is None
             context_dict = await self._storage.get(context_key)
-            assert isinstance(context_dict, dict)
+            assert isinstance(context_dict, dict) or context_dict is None
             context = Context(context_dict if context_dict is not None else {})
             bot_update = BotUpdate(state, context, update)
             handler = await self._handler_table.get_handler(self, bot_update)
@@ -363,12 +289,92 @@ class Bot(MutableMapping[str, Any], ApiMethods):
                 bot_logger.debug('Not found handler for update "%s". Skip.',
                                  update.update_id)
 
+    async def _start(self) -> None:
+        self._started = True
+
+        self._me = await self.get_me()
+        self._scheduler = await aiojobs.create_scheduler(
+            exception_handler=self._scheduler_exception_handler)
+
+    async def _cleanup(self) -> None:
+        assert self._client is not None
+        assert self._scheduler is not None
+        await self._scheduler.close()
+        await self._client.close()
+        await self._message_limit.clear()
+        await self._chat_limit.clear()
+        await self._group_limit.clear()
+
+    @abstractmethod
+    async def start(self) -> None: ...
+
+    @abstractmethod
+    async def stop(self) -> None: ...
+
+
+class PollBot(Bot):
+
+    def __init__(
+        self,
+        token: str,
+        handler_table: 'HandlerTableProtocol',
+        storage: StorageProtocol,
+        connector: Optional[BaseConnector] = None
+    ) -> None:
+        super().__init__(token, handler_table, storage, connector)
+        self._poll_task: Optional[asyncio.Task[None]] = None
+
+    async def start(self) -> None:
+        if self._started:
+            raise RuntimeError('Polling already started')
+        await self._start()
+        assert self._me is not None
+        self._poll_task = asyncio.create_task(self._poll_wrapper())
+        bot_logger.info('Bot %s (%s) start polling', self._me.first_name,
+                        self._me.username)
+
+    async def stop(self) -> None:
+        if not self._started:
+            raise RuntimeError('Polling not started')
+        if self._stopped:
+            raise RuntimeError('Polling already stopped')
+        assert self._poll_task is not None
+        bot_logger.debug('Stop polling')
+        self._stopped = True
+        if not self._poll_task.done():
+            self._poll_task.cancel()
+
+    async def _poll_wrapper(self) -> None:
+        assert self._me is not None
+        try:
+            await self._poll()
+        except asyncio.CancelledError:
+            pass
+        except Exception as exception:
+            bot_logger.exception('Error while polling updates',
+                                 exc_info=exception)
+        await self._cleanup()
+        bot_logger.info('Bot %s (%s) stop polling', self._me.first_name,
+                        self._me.username)
+
+    @backoff.on_exception(backoff.expo, TelegramError)
+    async def _poll(self) -> None:
+        assert self._scheduler is not None, 'Scheduler not initialized'
+        bot_logger.debug('Get updates from: %s', self._updates_offset)
+        while not self._stopped:
+            updates = await self.get_updates(offset=self._updates_offset,
+                                             timeout=TG_GET_UPDATES_TIMEOUT)
+            for update in updates:
+                await self._scheduler.spawn(self._handle_update(update))
+            if len(updates) > 0:
+                self._updates_offset = updates[-1].update_id + 1
+
 
 HandlerCallable = Callable[[Bot, BotUpdate], Awaitable[None]]
 FiltersType = Tuple['FilterProtocol', ...]
 
 
-@attr.s(slots=True, frozen=True, auto_attribs=True)
+@attr.s(frozen=True, auto_attribs=True)
 class Handler:
     callable: HandlerCallable
     filters: FiltersType
