@@ -3,9 +3,10 @@ from typing import Any, Dict, Final, Iterator, MutableMapping, Optional
 from .api_types import (CallbackQuery, ChosenInlineResult, InlineQuery,
                         Message, PreCheckoutQuery, ShippingQuery, Update)
 
+__all__ = ('Context', 'BotUpdate')
+
 
 class Context(MutableMapping[str, Any]):
-    __slots__ = '_data'
 
     def __init__(self, data: Dict[str, Any]) -> None:
         self._data: Final[Dict[str, Any]] = data
@@ -33,7 +34,6 @@ class Context(MutableMapping[str, Any]):
 
 
 class BotUpdate(MutableMapping[str, Any]):
-    __slots__ = '_state', '_context', '_update', '_data'
 
     def __init__(self, state: Optional[str], context: Context,
                  update: Update) -> None:
